@@ -14,9 +14,7 @@ use super::{
     register::{Entry, EntryHash},
     Safe, XorName,
 };
-pub use super::{
-    wallet::WalletSpendableBalances, SafeContentType, SafeDataType, SafeUrl, XorUrlBase,
-};
+pub use super::{SafeContentType, SafeDataType, SafeUrl, XorUrlBase};
 use crate::{Error, Result};
 use log::{debug, info};
 use serde::{Deserialize, Serialize};
@@ -34,14 +32,6 @@ pub enum SafeData {
         xorname: XorName,
         resolved_from: String,
     },
-    Wallet {
-        xorurl: String,
-        xorname: XorName,
-        type_tag: u64,
-        balances: WalletSpendableBalances,
-        data_type: SafeDataType,
-        resolved_from: String,
-    },
     FilesContainer {
         xorurl: String,
         xorname: XorName,
@@ -113,7 +103,6 @@ impl SafeData {
         use SafeData::*;
         match self {
             SafeKey { xorurl, .. }
-            | Wallet { xorurl, .. }
             | FilesContainer { xorurl, .. }
             | PublicBlob { xorurl, .. }
             | NrsMapContainer { xorurl, .. }
@@ -129,7 +118,6 @@ impl SafeData {
         use SafeData::*;
         match self {
             SafeKey { resolved_from, .. }
-            | Wallet { resolved_from, .. }
             | FilesContainer { resolved_from, .. }
             | PublicBlob { resolved_from, .. }
             | NrsMapContainer { resolved_from, .. }
@@ -148,12 +136,13 @@ impl Safe {
     /// ## Examples
     ///
     /// ### Fetch FilesContainer relative path file
-    /// ```rust
+    /// ```no_run
     /// # use sn_api::{Safe, fetch::SafeData};
     /// # use std::collections::BTreeMap;
     /// # let mut safe = Safe::default();
-    /// # async_std::task::block_on(async {
-    /// #   safe.connect("", Some("fake-credentials")).await.unwrap();
+    /// # let rt = tokio::runtime::Runtime::new().unwrap();
+    /// # rt.block_on(async {
+    /// #   safe.connect(None, None, None).await.unwrap();
     ///     let (xorurl, _, _) = safe.files_container_create(Some("../testdata/"), None, true, false, false).await.unwrap();
     ///
     ///     let safe_data = safe.fetch( &format!( "{}/test.md", &xorurl.replace("?v=0", "") ), None ).await.unwrap();
@@ -190,12 +179,13 @@ impl Safe {
     /// ## Examples
     ///
     /// ### Inspect FilesContainer relative path file
-    /// ```rust
+    /// ```no_run
     /// # use sn_api::{Safe, fetch::SafeData};
     /// # use std::collections::BTreeMap;
-    /// # let mut safe = Safe::default();
-    /// # async_std::task::block_on(async {
-    /// #   safe.connect("", Some("fake-credentials")).await.unwrap();
+    /// # let rt = tokio::runtime::Runtime::new().unwrap();
+    /// # rt.block_on(async {
+    /// #   let mut safe = Safe::default();
+    /// #   safe.connect(None, None, None).await.unwrap();
     ///     let (container_xorurl, _, _) = safe.files_container_create(Some("../testdata/"), None, true, false, false).await.unwrap();
     ///
     ///     let inspected_content = safe.inspect( &format!( "{}/test.md", &container_xorurl.replace("?v=0", "") ) ).await.unwrap();
@@ -308,7 +298,7 @@ impl Safe {
                     match &files_map.get(&realpath) {
                         Some(file_item) => match file_item.get("type") {
                             Some(file_type) => {
-                                if FileMeta::filetype_is_file(&file_type) {
+                                if FileMeta::filetype_is_file(file_type) {
                                     match file_item.get("link") {
                                         Some(link) => {
                                             let new_target_xorurl = SafeUrl::from_url(link)?;
@@ -326,7 +316,7 @@ impl Safe {
                                             return Err(Error::ContentError(msg));
                                         }
                                     }
-                                } else if FileMeta::filetype_is_symlink(&file_type) {
+                                } else if FileMeta::filetype_is_symlink(file_type) {
                                     let msg = format!(
                                         "symlink should not be present in resolved real path. {}",
                                         realpath
@@ -556,35 +546,9 @@ impl Safe {
                     ))),
                 }
             }
-            SafeContentType::Wallet => {
-                if !the_xor.sub_names_vec().is_empty() {
-                    let msg = format!(
-                        "Cannot resolve Wallet URL as it contains subnames: {}",
-                        xorurl
-                    );
-                    debug!("{}", msg);
-                    return Err(Error::InvalidXorUrl(msg));
-                }
-
-                // TODO: do the _actual_fetch
-                // let balances = WalletSpendableBalances::new();
-                let balances = if retrieve_data {
-                    self.fetch_wallet(&the_xor).await?
-                } else {
-                    WalletSpendableBalances::new()
-                };
-
-                let safe_data = SafeData::Wallet {
-                    xorurl,
-                    xorname: the_xor.xorname(),
-                    type_tag: the_xor.type_tag(),
-                    balances,
-                    data_type: the_xor.data_type(),
-                    resolved_from: url,
-                };
-
-                Ok((safe_data, None))
-            }
+            SafeContentType::Wallet { .. } => Err(Error::EmptyContent(
+                "Temporarily disabled feature".to_string(),
+            )),
         }
     }
 
@@ -660,56 +624,6 @@ mod tests {
     use rand::{distributions::Alphanumeric, thread_rng, Rng};
     use std::io::Read;
 
-    #[tokio::test]
-    async fn test_fetch_key() -> Result<()> {
-        let mut safe = new_safe_instance().await?;
-        let preload_amount = "1324.12";
-        let (xorurl, _key_pair) = safe.keys_create_preload_test_coins(preload_amount).await?;
-
-        let safe_url = SafeUrl::from_url(&xorurl)?;
-        let content = retry_loop!(safe.fetch(&xorurl, None));
-        assert!(
-            content
-                == SafeData::SafeKey {
-                    xorurl: xorurl.clone(),
-                    xorname: safe_url.xorname(),
-                    resolved_from: xorurl.clone(),
-                }
-        );
-
-        // let's also compare it with the result from inspecting the URL
-        let inspected_content = safe.inspect(&xorurl).await?;
-        assert_eq!(inspected_content.len(), 1);
-        assert_eq!(content, inspected_content[0]);
-        Ok(())
-    }
-
-    #[tokio::test]
-    async fn test_fetch_wallet() -> Result<()> {
-        let mut safe = new_safe_instance().await?;
-        let xorurl = safe.wallet_create().await?;
-
-        let safe_url = SafeUrl::from_url(&xorurl)?;
-        let content = retry_loop!(safe.fetch(&xorurl, None));
-        assert!(
-            content
-                == SafeData::Wallet {
-                    xorurl: xorurl.clone(),
-                    xorname: safe_url.xorname(),
-                    type_tag: 1_000,
-                    balances: WalletSpendableBalances::default(),
-                    data_type: SafeDataType::SeqMap,
-                    resolved_from: xorurl.clone(),
-                }
-        );
-
-        // let's also compare it with the result from inspecting the URL
-        let inspected_content = safe.inspect(&xorurl).await?;
-        assert_eq!(inspected_content.len(), 1);
-        assert_eq!(content, inspected_content[0]);
-        Ok(())
-    }
-
     #[tokio::test]
     async fn test_fetch_files_container() -> Result<()> {
         let mut safe = new_safe_instance().await?;
